@@ -6,12 +6,12 @@ from .main import SqlCreds, to_sql
 from .utils import bcp
 
 name = "bcpandas"
-__version__ = "0.6.0"
+__version__ = "1.0.1"
 
 
 # BCP check
 try:
-    run(["bcp", "-v"], stdout=DEVNULL, stderr=DEVNULL)
+    run(["bcp", "-v"], stdout=DEVNULL, stderr=DEVNULL, stdin=DEVNULL)
 except FileNotFoundError:
     warnings.warn("BCP utility not installed or not found in PATH, bcpandas will not work!")
 
